@@ -1,7 +1,7 @@
 package Dancer::Config;
 our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT:  how to configure Dancer to suit your needs
-$Dancer::Config::VERSION = '1.3402'; # TRIAL
+$Dancer::Config::VERSION = '1.3403'; # TRIAL
 use strict;
 use warnings;
 use base 'Exporter';
@@ -190,11 +190,7 @@ sub load {
     return 1 unless -f conffile;
 
     # load YAML
-    my $module = $SETTINGS->{engines}{YAML}{module} || 'YAML';
-
-    my ( $result, $error ) = Dancer::ModuleLoader->load($module);
-    confess "Configuration file found but could not load $module: $error"
-        unless $result;
+    my $module = load_yaml_module();
 
     unless ($_LOADED{conffile()}) {
         load_settings_from_yaml(conffile, $module);
@@ -228,7 +224,7 @@ sub load {
 sub load_settings_from_yaml {
     my ($file, $module) = @_;
 
-    $module ||= 'YAML';
+    $module ||= load_yaml_module();
 
     my $config;
     {
@@ -246,6 +242,18 @@ sub load_settings_from_yaml {
     return scalar keys %$config;
 }
 
+sub load_yaml_module {
+    my ($module) = @_;
+
+    $module ||= $SETTINGS->{engines}{YAML}{module} || 'YAML';
+
+    my ( $result, $error ) = Dancer::ModuleLoader->load($module);
+    confess "Could not load $module: $error"
+        unless $result;
+
+    return $module;
+}
+
 sub load_default_settings {
     $SETTINGS->{server}        ||= $ENV{DANCER_SERVER}        || '0.0.0.0';
     $SETTINGS->{port}          ||= $ENV{DANCER_PORT}          || '3000';
@@ -284,7 +292,7 @@ Dancer::Config - how to configure Dancer to suit your needs
 
 =head1 VERSION
 
-version 1.3402
+version 1.3403
 
 =head1 DESCRIPTION
 
@@ -357,6 +365,16 @@ If set to true, Dancer will look to C<X-Forwarded-Protocol> and
 C<X-Forwarded-host> when constructing URLs (for example, when using
 C<redirect>. This is useful if your application is behind a proxy.
 
+It will also cause L<< Dancer::Request->address|Dancer::Request/address >>
+to return what L<< Dancer::Request->forwarded_for_address|Dancer::Request/forwarded_for_address >>
+would return, namely the content of the `HTTP_X_FORWARDED_FOR` env var/header,
+so that requests will appear to have come from the end user's IP and
+not the proxy's.
+
+Because of the above, you should *not* turn this on if your app isn't
+behind a proxy which will pass this information on appropriately, otherwise
+a malicious user could supply false information.
+
 =head2 Content type / character set
 
 =head3 content_type (string)
