@@ -1,7 +1,7 @@
 package Dancer::Session::YAML;
 our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: YAML-file-based session backend for Dancer
-$Dancer::Session::YAML::VERSION = '1.3402'; # TRIAL
+$Dancer::Session::YAML::VERSION = '1.3403'; # TRIAL
 use strict;
 use warnings;
 use Carp;
@@ -69,7 +69,7 @@ sub retrieve {
 
     my $session_file = yaml_file($id);
 
-    return unless -f $session_file;
+    return unless defined $session_file && -f $session_file;
 
     open my $fh, '+<', $session_file or die "Can't open '$session_file': $!\n";
     my $content = YAML::LoadFile($fh);
@@ -123,7 +123,7 @@ Dancer::Session::YAML - YAML-file-based session backend for Dancer
 
 =head1 VERSION
 
-version 1.3402
+version 1.3403
 
 =head1 DESCRIPTION
 
